@@ -7,7 +7,7 @@ import os
 import re
 import warnings
 from json import JSONEncoder
-
+from typing import Optional, Dict
 import asteval
 from CoolProp.CoolProp import PropsSI
 
@@ -87,14 +87,16 @@ class Material:
             temperature have density equations that depend on temperature.
             These tend to be liquids and gases used for coolants and even
             liquids such as lithium-lead and FLiBe that are used as a breeder
-            materials.
+            materials. Convered to K and added to the openmc material object
+            and the serpent material card.
         temperature_in_K (float): The temperature of the material in degrees
             Kelvin. Temperature impacts the density of some materials in the
             collection. Materials in the collection that are impacted by
             temperature have density equations that depend on temperature.
             These tend to be liquids and gases used for coolants and even
             liquids such as lithium-lead and FLiBe that are used as breeder
-            materials.
+            materials. Added to the openmc material object and the serpent
+            material card.
         pressure_in_Pa (float): The pressure of the material in Pascals
             Pressure impacts the density of some materials in the
             collection. Materials in the collection that are impacted by
@@ -138,29 +140,29 @@ class Material:
 
     def __init__(
         self,
-        material_name=None,
-        packing_fraction=1.0,
-        material_tag=None,
-        enrichment=None,
-        enrichment_target=None,
-        temperature_in_C=None,
-        temperature_in_K=None,
-        pressure_in_Pa=None,
-        elements=None,
-        chemical_equation=None,
-        isotopes=None,
-        percent_type=None,
-        density=None,
-        density_unit=None,
-        density_equation=None,
-        atoms_per_unit_cell=None,
-        volume_of_unit_cell_cm3=None,
-        enrichment_type=None,
-        reference=None,
-        zaid_suffix=None,
-        material_id=None,
-        decimal_places=8,
-        volume_in_cm3=None,
+        material_name: Optional[str] = None,
+        packing_fraction: Optional[float] = 1.0,
+        material_tag: Optional[str] = None,
+        enrichment: Optional[float] = None,
+        enrichment_target: Optional[str] = None,
+        temperature_in_C: Optional[float] = None,
+        temperature_in_K: Optional[float] = None,
+        pressure_in_Pa: Optional[float] = None,
+        elements: Optional[Dict[str, float]] = None,
+        chemical_equation: Optional[str] = None,
+        isotopes: Optional[Dict[str, float]] = None,
+        percent_type: Optional[str] = None,
+        density: Optional[float] = None,
+        density_unit: Optional[str] = None,
+        density_equation: Optional[str] = None,
+        atoms_per_unit_cell: Optional[int] = None,
+        volume_of_unit_cell_cm3: Optional[float] = None,
+        enrichment_type: Optional[str] = None,
+        reference: Optional[str] = None,
+        zaid_suffix: Optional[str] = None,
+        material_id: Optional[int] = None,
+        decimal_places: Optional[int] = 8,
+        volume_in_cm3: Optional[float] = None,
     ):
 
         self.material_name = material_name
@@ -235,7 +237,7 @@ class Material:
                     if temperature_in_K is None:
                         self.temperature_in_K = temperature_in_C + 273.15
                     if temperature_in_C is None:
-                        self.temperature_in_C = temperature_in_K + 273.15
+                        self.temperature_in_C = temperature_in_K - 273.15
 
             if "pressure_dependant" in material_dict[self.material_name].keys(
             ):
@@ -601,9 +603,13 @@ class Material:
             name = self.material_tag
         if self.material_id is not None:
             openmc_material = openmc.Material(
-                material_id=self.material_id, name=name)
+                material_id=self.material_id,
+                name=name,
+                temperature=self.temperature_in_K)
         else:
-            openmc_material = openmc.Material(name=name)
+            openmc_material = openmc.Material(
+                name=name,
+                temperature=self.temperature_in_K)
 
         if self.isotopes is not None:
 
